THE BOOST MPL LIBRARY: Dependencies

Front Page / Technical Details / Dependencies

# Dependencies

Besides Boost.Config headers, the MPL relies on three other header-only libraries:

- Boost.Preprocessor
- Boost.Type Traits
- Boost.Static Assert

These dependencies are essential and cannot be eliminated. The library's tests and examples may depend on some additional Boost libraries such as Boost.Bind; unless you are interested in actually compiling these files, you can safely ignore those dependencies.